@@ -17,7 +17,7 @@ simulate(
                 ## C uses zero-based indexing!
                 parindex <- match(paramnames,rownames(params))-1
                 array(
-                      .C("ou2_adv",
+                      .C("_ou2_adv",
                          X = double(nvar*nrep*ntimes),
                          xstart = as.double(xstart),
                          par = as.double(params),
@@ -39,7 +39,7 @@ simulate(
                 ntimes <- length(times)
                 parindex <- match(paramnames,rownames(params))-1
                 array(
-                      .C("ou2_pdf",
+                      .C("_ou2_pdf",
                          d = double(nrep*(ntimes-1)),
                          X = as.double(x),
                          par = as.double(params),
@@ -54,8 +54,8 @@ simulate(
                       dim=c(nrep,ntimes-1)
                       )
               },
-              dmeasure = "ou2_normal_dmeasure",
-              rmeasure = "ou2_normal_rmeasure",
+              dmeasure = "_ou2_normal_dmeasure",
+              rmeasure = "_ou2_normal_rmeasure",
               skeleton.map = function (x, t, params, ...) {
                 with(
                      as.list(c(x,params)),
